datasets - MultiMolecule
Author: MultiMolecule
Description: Neural Networks for RNA, DNA, and Protein

Skip to content

# datasets

`datasets` provide a collection of widely used datasets.

## Available Datasets

### DeoxyriboNucleic Acid (DNA)

- GeneCode

### RiboNucleic acid (RNA)

- RNACentral
- Rfam
- bpRNA-1m

2024-06-25 15:24:27

#### Cookie Consent

We use cookies to recognize your repeated visits and preferences, as well as to measure the effectiveness of our documentation and whether users find what they're searching for. With your consent, you're helping us to make our documentation better. Please check out our Privacy Notice for more information.

- Google Analytics
- GitHub

Manage settings